<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>Platzhalter-Seite</h3>

Diese Seite wurde noch nicht ausformuliert.
<pre> </pre>


<font size="-1">
<i>Warum enthält diese Dokumentation leere Seiten?</i><p>
Wir brauchen die Platzhalter-Seiten damit an anderen Stellen der
Dokumentation bereits die passenden Querverweise gesetzt werden können. 

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
